Sanzang Lib
===========

The Sanzang Library is a Python 3 module for translating from Chinese,
Japanese, and Korean (the CJK languages). The Sanzang Library implements the
main functions of the programs contained in Sanzang Utils.

Installation
------------

To install this module, you can use pip or just the normal setup script::

    # python3 setup.py install

Usage and documentation
-----------------------

To begin using the module, you can just import it::

    import sanzang

To read about which functions are available and their usage, you could do::

    >>> import sanzang
    >>> help(sanzang)

Project links
-------------

* *GitHub: sanzang-lib* <https://github.com/yaoguai/sanzang-lib>
* *GitHub: sanzang-utils* <https://github.com/yaoguai/sanzang-utils>
* *Sanzang Homepage* <http://lapislazulitexts.com/sanzang>
* *Sanzang: Introduction* <http://lapislazulitexts.com/articles/sanzang_intro>
* *Sanzang Utils Tutorial* <http://lapislazulitexts.com/articles/szu_tutorial>
